@@ -11,7 +11,7 @@ import requests
 from docker.errors import ImageNotFound  # type: ignore
 
 from treebeard.buildtime.helper import run_image
-from treebeard.conf import run_path, treebeard_env, get_treebeard_config
+from treebeard.conf import get_treebeard_config, run_path, treebeard_env
 from treebeard.helper import sanitise_notebook_id
 from treebeard.util import fatal_exit
 
@@ -27,6 +27,22 @@ def download_archive(unzip_location: str, download_location: str, url: str):
     # rm {download_location}""",
 
 
+def fetch_image_for_cache(client: Any, image_name: str, project_base_image: str):
+    try:
+        click.echo(f"Pulling {image_name}")
+        client.images.pull(image_name)
+    except requests.exceptions.ConnectionError:
+        fatal_exit("Could not connect to Docker registry!")
+    except ImageNotFound:
+        try:
+            click.echo(
+                f"Could not pull {image_name}, instead pulling {project_base_image}"
+            )
+            client.images.pull(project_base_image)
+        except Exception as ex:
+            click.echo(f"Error pulling project base image {ex}, continuing without...")
+
+
 def run_repo(
     project_id: str,
     notebook_id: str,
@@ -34,6 +50,7 @@ def run_repo(
     build_tag: str,
     repo_url: str,
     secrets_url: Optional[str],
+    branch: str,
     local: bool = False,
 ) -> int:
     click.echo(f"🌲 Treebeard buildtime, building repo")
@@ -73,26 +90,17 @@ def run_repo(
 
     # Pull down images to use in cache
     image_name = f"gcr.io/treebeard-259315/projects/{project_id}/{sanitise_notebook_id(notebook_id)}"
-    # our "base" image is just a routine repo2docker build which can be used for caching
-    project_base_image = "docker.io/treebeardtech/project-base-image"
-
-    try:
-        click.echo(f"Pulling {image_name}")
-        client.images.pull(image_name)
-    except requests.exceptions.ConnectionError:
-        fatal_exit("Could not connect to Docker registry!")
-    except ImageNotFound:
-        try:
-            click.echo(
-                f"Could not pull {image_name}, instead pulling {project_base_image}"
-            )
-            client.images.pull(project_base_image)
-        except Exception as ex:
-            click.echo(f"Error pulling project base image {ex}, continuing without...")
 
     # Build image but don't run
     versioned_image_name = f"{image_name}:{build_tag}"
-    latest_image_name = f"{image_name}:latest"
+    passing_image_name = f"{image_name}:{branch}"
+    latest_image_name = f"{image_name}:{branch}-latest"
+
+    # our "base" image is just a routine repo2docker build which can be used for caching
+    project_base_image = "docker.io/treebeardtech/project-base-image"
+
+    if not local:
+        fetch_image_for_cache(client, latest_image_name, project_base_image)
 
     user_name = "project_user"  # All images having the same home dir enables caching
     r2d = f"""
@@ -110,14 +118,19 @@ def run_repo(
 
     try:
         subprocess.check_output(["bash", "-c", r2d])
+        click.echo(f"✨  Successfully built {versioned_image_name}")
     except:
         click.echo(f"\n\n❗ Failed to build container from the source repo")
         return 1
 
+    subprocess.check_output(["docker", "tag", versioned_image_name, latest_image_name])
     if not local:
         try:
-            click.echo(f"Image built: Pushing {versioned_image_name}")
+            click.echo(
+                f"Image built: Pushing {versioned_image_name} and {latest_image_name}"
+            )
             client.images.push(versioned_image_name)
+            client.images.push(latest_image_name)  # this tag is necessary for caching
         except Exception:
             click.echo(
                 f"Failed to push image, will try again on success\n{format_exc()}"
@@ -126,11 +139,11 @@ def run_repo(
     click.echo(f"Image built successfully, now running.")
     status = run_image(project_id, notebook_id, run_id, versioned_image_name)
     if status != 0:
-        click.echo("Image run failed, not updated :latest")
+        click.echo(f"Image run failed, not updated {passing_image_name}")
         return status
 
-    subprocess.check_output(["docker", "tag", versioned_image_name, latest_image_name])
-    click.echo(f"tagged {versioned_image_name} as {latest_image_name}")
+    subprocess.check_output(["docker", "tag", versioned_image_name, passing_image_name])
+    click.echo(f"tagged {versioned_image_name} as {passing_image_name}")
     return 0
 
 
@@ -138,6 +151,7 @@ if __name__ == "__main__":
     build_tag_key = "TREEBEARD_BUILD_TAG"
     repo_url_key = "TREEBEARD_REPO_URL"
     secrets_url_key = "TREEBEARD_SECRETS_URL"
+    branch_key = "TREEBEARD_BRANCH"
 
     subprocess.run(["bash", "-c", "echo Building repo"])
 
@@ -145,6 +159,10 @@ if __name__ == "__main__":
     if not build_tag:
         fatal_exit(f"No build_tag provided inside {build_tag_key}")
 
+    branch = os.getenv(branch_key)
+    if not branch:
+        fatal_exit(f"No branch provided inside {branch_key}")
+
     repo_url = os.getenv(repo_url_key)
     if not repo_url:
         fatal_exit(f"No repo_url provided inside {repo_url_key}")
@@ -162,6 +180,7 @@ if __name__ == "__main__":
         build_tag,
         repo_url,
         secrets_url,
+        branch,
     )
 
     sys.exit(status)
