@@ -41,10 +41,10 @@ def run_notebook(notebook_path: str) -> str:
         pm.execute_notebook(  # type: ignore
             notebook_path,
             notebook_path,
+            kernel_name=treebeard_config.kernel_name,
             progress_bar=False,
             request_save_on_cell_execute=True,
             autosave_cell_every=10,
-            kernel_name="python3",
             log_output=True,
             cwd=f"{os.getcwd()}/{notebook_dir}",
         )
@@ -96,7 +96,7 @@ def start():
         raise Exception("No project ID at buildtime")
 
     notebook_statuses = run(
-        treebeard_env.project_id, treebeard_env.notebook_id, treebeard_env.run_id
+        treebeard_env.project_id, treebeard_env.notebook_id, treebeard_env.run_id  # type: ignore
     )
 
     for notebook in notebook_statuses.keys():
